@@ -1,6 +1,11 @@
+require 'rubygems'
 require 'test/unit'
 
+gem 'mocha', '>= 0.9.5'
+require 'mocha'
+
 $:.unshift "#{File.dirname(__FILE__)}/../lib"
+$:.unshift "#{File.dirname(__FILE__)}/../../activesupport/lib"
 require 'active_resource'
 require 'active_resource/http_mock'
 
@@ -10,17 +15,9 @@ require 'setter_trap'
 ActiveResource::Base.logger = Logger.new("#{File.dirname(__FILE__)}/debug.log")
 
 def uses_gem(gem_name, test_name, version = '> 0')
-  require 'rubygems'
   gem gem_name.to_s, version
   require gem_name.to_s
   yield
 rescue LoadError
   $stderr.puts "Skipping #{test_name} tests. `gem install #{gem_name}` and try again."
 end
-
-# Wrap tests that use Mocha and skip if unavailable.
-unless defined? uses_mocha
-  def uses_mocha(test_name, &block)
-    uses_gem('mocha', test_name, '>= 0.5.5', &block)
-  end
-end
